@@ -19,6 +19,7 @@ try:
 except ImportError:
     from .compat import cached_property
 
+from .config import ShowDefaults
 from .context import ctx
 from .exceptions import ParameterDefinitionError, BadArgument, MissingArgument, InvalidChoice, CommandDefinitionError
 from .exceptions import ParamUsageError, ParamConflict, ParamsMissing, NoActiveContext
@@ -166,7 +167,7 @@ class ParamBase(ABC):
         raise NotImplementedError
 
     @abstractmethod
-    def format_help(self, width: int = 30, add_default: Bool = True) -> str:
+    def format_help(self, width: int = 30) -> str:
         raise NotImplementedError
 
 
@@ -373,14 +374,11 @@ class ParamGroup(ParamBase):
         choices = ','.join(mem.format_usage(include_meta, full, delim) for mem in self.members)
         return f'{{{choices}}}'
 
-    def format_help(
-        self, width: int = 30, add_default: Bool = True, group_type: Bool = True, clean: Bool = True
-    ) -> str:
+    def format_help(self, width: int = 30, group_type: Bool = True, clean: Bool = True) -> str:
         """
         Prepare the help text for this group.
 
         :param width: The width of the option/action/command column.
-        :param add_default: Whether default values should be included in the help text for parameters.
         :param group_type: Whether the group type should be included in the description if this is a mutually
           exclusive / dependent group
         :param clean: If this group only contains other groups or Action or SubCommand parameters, then omit the
@@ -399,7 +397,7 @@ class ParamGroup(ParamBase):
                 parts.append('')  # Add space for readability
             else:
                 params += 1
-            parts.append(member.format_help(width=width, add_default=add_default))
+            parts.append(member.format_help(width=width))
 
         if clean and nested and not params:
             parts = parts[2:]  # remove description and the first spacer
@@ -643,10 +641,10 @@ class Parameter(ParamBase, ABC):
     def format_usage(self, include_meta: Bool = False, full: Bool = False, delim: str = ', ') -> str:
         return self.usage_metavar
 
-    def format_help(self, width: int = 30, add_default: Bool = True) -> str:
+    def format_help(self, width: int = 30) -> str:
         usage = self.format_usage(include_meta=True, full=True)
         description = self.help or ''
-        if add_default and self.default is not _NotSet:
+        if _should_add_default(self.default, self.help):
             pad = ' ' if description else ''
             description += f'{pad}(default: {self.default})'
         return HelpEntryFormatter(usage, description, width)()
@@ -903,7 +901,6 @@ class ChoiceMap(BasePositional):
                 raise InvalidChoice(self, prefix[:-1], choices)
         elif value.startswith('-'):
             raise BadArgument(self, f'invalid value={value!r}')
-        # TODO: Should this raise an error?
 
     def result_value(self) -> Optional[str]:
         choices = self.choices
@@ -941,7 +938,7 @@ class ChoiceMap(BasePositional):
     def format_usage(self, include_meta: Bool = None, full: Bool = None, delim: str = None) -> str:
         return self.usage_metavar
 
-    def format_help(self, width: int = 30, add_default: Bool = None):
+    def format_help(self, width: int = 30):
         title = self.title or self._default_title
         help_entry = HelpEntryFormatter(self.format_usage(), self.description, width, lpad=2)()
         parts = [f'{title}:', help_entry]
@@ -1305,6 +1302,7 @@ class ActionFlag(Flag, repr_attrs=('order', 'before_main')):
         order: Union[int, float] = 1,
         func: Callable = None,
         before_main: Bool = True,  # noqa
+        always_available: Bool = False,
         **kwargs,
     ):
         """
@@ -1318,18 +1316,22 @@ class ActionFlag(Flag, repr_attrs=('order', 'before_main')):
         :param func: The function to execute when this parameter is specified.
         :param before_main: Whether this ActionFlag should be executed before the :meth:`.Command.main` method or
           after it.
+        :param always_available: Whether this ActionFlag should always be available to be called, even if parsing
+          failed.  Only allowed when ``before_main=True``.  The intended use case is for actions like ``--help`` text.
         :param kwargs: Additional keyword arguments to pass to :class:`Flag`.
         """
-        # TODO: Test in groups, esp mutually excl/dependent
         expected = {'action': 'store_const', 'default': False, 'const': _NotSet}
         found = {k: kwargs.setdefault(k, v) for k, v in expected.items()}
         bad = {k: v for k, v in found.items() if expected[k] != v}
         if bad:
             raise ParameterDefinitionError(f'Unsupported kwargs for {self.__class__.__name__}: {bad}')
+        elif always_available and not before_main:
+            raise ParameterDefinitionError('always_available=True cannot be combined with before_main=False')
         super().__init__(*option_strs, **kwargs)
         self.func = func
         self.order = order
         self.before_main = before_main
+        self.always_available = always_available
 
     @property
     def func(self):
@@ -1498,3 +1500,23 @@ class PassThru(Parameter):
     def format_basic_usage(self) -> str:
         usage = self.format_usage()
         return f'-- {usage}' if self.required else f'[-- {usage}]'
+
+
+# region Helper Functions
+
+
+def _should_add_default(default: Any, help_text: Optional[str]) -> bool:
+    if default is _NotSet:
+        return False
+    sd = ctx.show_defaults
+    if sd.value < 2 or (sd & ShowDefaults.MISSING and help_text and 'default:' in help_text):
+        return False
+    elif sd & ShowDefaults.ANY:
+        return True
+    elif sd & ShowDefaults.NON_EMPTY:
+        return bool(default) or not (default is None or isinstance(default, Collection))
+    else:
+        return bool(default)
+
+
+# endregion
